SDCflows
--------

.. image:: https://circleci.com/gh/nipreps/sdcflows.svg?style=svg
    :target: https://circleci.com/gh/nipreps/sdcflows

.. image:: https://img.shields.io/pypi/v/sdcflows.svg
  :target: https://pypi.python.org/pypi/sdcflows/
  :alt: Latest Version


SDCflows (susceptibility distortion correction workflows) is a library of workflows
to correct for distortions typically remaining after reconstruction in images
acquired with EPI (echo-planar imaging) MR schemes.
It is designed to provide an easily accessible, state-of-the-art interface that is
robust to differences in scan acquisition protocols and that requires minimal user input.

This open-source neuroimaging data processing tool is being developed as a part of
the MRI image analysis and reproducibility platform offered by the CRN.
